import React from 'react'
import { useDrag, useDrop } from 'react-dnd'
import { Icon } from 'antd'
import ItemTypes from './itemtypes'
import './index.scss'

const Card = ({ id, text, moveCard, findCard, editCard }) => {
  const originalIndex = findCard(id).index
  const [{ isDragging }, drag] = useDrag({
    item: { type: ItemTypes.CARD, id, originalIndex },
    collect: monitor => ({
      isDragging: monitor.isDragging(),
    }),
  })
  const [, drop] = useDrop({
    accept: ItemTypes.CARD,
    canDrop: () => false,
    hover({ id: draggedId }) {
      if (draggedId !== id) {
        const { index: overIndex } = findCard(id)
        moveCard(draggedId, overIndex)
      }
    },
  })
  const opacity = isDragging ? 0 : 1

  const edit = () => {
    editCard(id)
  }
  return (
    <div className="card" style={{ opacity }}>
      <div ref={node => drag(drop(node))}>
        {text}
      </div>
      <Icon className="edit" type="edit" onClick={edit} />
    </div>
  )
}
export default Card
